@@ -8,6 +8,13 @@ class PyChromecastError(Exception):
     pass
 
 
+class NoChromecastFoundError(PyChromecastError):
+    """
+    When a command has to auto-discover a Chromecast and cannot find one.
+    """
+    pass
+
+
 class ConnectionError(PyChromecastError):
     """ When a connection error occurs within PyChromecast. """
     pass
